Modulegraph - Python module dependency graph — modulegraph 0.11.1 documentation

### Navigation

- index
- modules |
- next |
- modulegraph 0.11.1 documentation »

# Modulegraph - Python module dependency graph

modulegraph determines a dependency graph between Python modules primarily by bytecode analysis for import statements.

modulegraph uses similar methods to `modulefinder` from the standard library, but uses a more flexible internal representation, has more extensive knowledge of special cases, and is extensible.

Contents:

- Release history
- License
- Commandline tools
- `modulegraph.modulegraph` — Find modules used by a script
- `modulegraph.find_modules` — High-level module dependency finding interface
- `modulegraph.util` — Utilies functions
- `modulegraph.zipio` — Read-only filesystem access

## Online Resources

- Sourcecode repository on bitbucket
- The issue tracker

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- modulegraph 0.11.1 documentation »